LogRecord class

Constructors

LogRecord(Level level, Object message, String? tag, LoggerStackTrace contextInfo, {Object? error, StackTrace? stackTrace, String? loggerName, String? dateFormat})

Properties

className String?
no setter
contextInfo LoggerStackTrace
final
dateFormat String?
final
error Object?
final
hashCode int
The hash code for this object.
no setterinherited
level Level
final
lineNumber int?
no setter
loggerName String?
getter/setter pair
message Object
final
methodName String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
final
tag String?
final
time DateTime
getter/setter pair

Methods

functionNameAndLine() String
Returns formatted function name and line for %c placeholder Format: "ClassName.methodName:lineNumber" or just "methodName:lineNumber"
getFormattedTime() String
inFileLocation() String?
Returns the file location for %f placeholder Format: "package:example/path/file.dart(line:column)" or "file:///path/file.dart(line:column)"
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited