AppenderBuilder class
A builder class for programmatically creating and configuring Appender instances.
Constructors
- AppenderBuilder(String _type)
-
Creates a new builder for the specified
AppenderType.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
{bool test = false, DateTime? date}) → Future< Appender> - Builds the appender asynchronously using the specified configuration.
-
buildSync(
) → Appender - Builds the appender synchronously (only for CONSOLE)
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
withDateFormat(
String dateFormat) → AppenderBuilder - Sets the date format pattern to be used in the log message.
-
withDepthOffset(
int offset) → AppenderBuilder - Sets the client depth offset for call stack analysis.
-
withEnabledState(
bool enabled) → AppenderBuilder - Sets the initial enabled state of the appender.
-
withFormat(
String format) → AppenderBuilder - Sets the log message format pattern.
-
withLevel(
Level level) → AppenderBuilder - Sets the logging Level for the appender.
-
withRotationCycle(
RotationCycle cycle) → AppenderBuilder - Sets the RotationCycle for log file rotation.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited